abctools.ScoreSelection
=======================

.. inheritance-diagram:: abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection
   :private-bases:

.. autoclass:: abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection.music

.. autoattribute:: abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection.__contains__

.. automethod:: abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection.__eq__

.. automethod:: abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection.__getitem__

.. automethod:: abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection.__len__

.. automethod:: abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection.__ne__

.. automethod:: abjad.tools.abctools.ScoreSelection.ScoreSelection.ScoreSelection.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
